pub struct SdkLwkSigner { /* private fields */ }Expand description
A software signer
Implementations
Sourceimpl SdkLwkSigner
impl SdkLwkSigner
Sourcepub fn new(sdk_signer: Arc<Box<dyn Signer>>) -> Result<Self, NewError>
pub fn new(sdk_signer: Arc<Box<dyn Signer>>) -> Result<Self, NewError>
Creates a new software signer from the given mnemonic.
Takes also a flag if the network is mainnet so that generated extended keys are in the correct form xpub/tpub (there is no need to discriminate between regtest and testnet)
pub fn fingerprint(&self) -> Result<Fingerprint, SignError>